summaryrefslogtreecommitdiffstats
path: root/kmail/messagecomposer.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-13 00:46:47 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-04-13 00:46:47 +0000
commit67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7 (patch)
tree5f52a9eada2e9f3654fc327d7c14dfef570a6ecb /kmail/messagecomposer.cpp
parent2ee4bf4fd5eff93b2fbef0ff8e8063edffc5da5c (diff)
downloadtdepim-67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7.tar.gz
tdepim-67e29a054cfcb1b0d2fe6b0a316cf6b3eec087b7.zip
Initial conversion of kdepim to TQt
This will probably require some tweaking before it will build under Qt4, however Qt3 builds are OK. Any alterations this commit makes to kdepim behaviour under Qt3 are unintentional and should be fixed. git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1227832 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kmail/messagecomposer.cpp')
-rw-r--r--kmail/messagecomposer.cpp32
1 files changed, 16 insertions, 16 deletions
diff --git a/kmail/messagecomposer.cpp b/kmail/messagecomposer.cpp
index 2ff7cd6a..897b03e6 100644
--- a/kmail/messagecomposer.cpp
+++ b/kmail/messagecomposer.cpp
@@ -18,11 +18,11 @@
*
* In addition, as a special exception, the copyright holders give
* permission to link the code of this program with any edition of
- * the Qt library by Trolltech AS, Norway (or with modified versions
- * of Qt that use the same license as Qt), and distribute linked
+ * the TQt library by Trolltech AS, Norway (or with modified versions
+ * of TQt that use the same license as TQt), and distribute linked
* combinations including the two. You must obey the GNU General
* Public License in all respects for all of the code used other than
* Qt. If you modify this file, you may extend this exception to
* your version of the file, but you are not obligated to do so. If
* you do not wish to do so, delete this exception statement from
* your version.
@@ -521,7 +521,7 @@ void MessageComposer::readFromComposeWin()
mEncryptWithChiasmus = mComposeWin->mEncryptWithChiasmus;
- mIsRichText = mComposeWin->mEditor->textFormat() == Qt::RichText;
+ mIsRichText = mComposeWin->mEditor->textFormat() == TQt::RichText;
mIdentityUid = mComposeWin->identityUid();
mText = breakLinesAndApplyCodec();
assert( mText.isEmpty() || mText[mText.size()-1] == '\n' );
@@ -1000,7 +1000,7 @@ void MessageComposer::composeMessage()
}
//
-// These are tqreplacements for StructuringInfo(Wrapper):
+// These are replacements for StructuringInfo(Wrapper):
//
// check whether to use multipart/{signed,encrypted}
@@ -1137,7 +1137,7 @@ static inline GpgME::Context::SignatureMode signingMode( Kleo::CryptoMessageForm
}
//
-// END tqreplacements for StructuringInfo(Wrapper)
+// END replacements for StructuringInfo(Wrapper)
//
class EncryptMessageJob : public MessageComposerJob {
@@ -1475,7 +1475,7 @@ void MessageComposer::composeMessage( KMMessage& theMessage,
newbody += "--";
newbody += boundaryCStr;
newbody += "--\n";
- bodyData = KMail::Util::byteArrayFromQCStringNoDetach( newbody );
+ bodyData = KMail::Util::byteArrayFromTQCStringNoDetach( newbody );
mOldBodyPart.setBodyEncodedBinary( bodyData );
mSaveBoundary = tmpCT.Boundary();
@@ -1527,7 +1527,7 @@ void MessageComposer::composeMessage( KMMessage& theMessage,
innerDwPart->Assemble();
TQByteArray tmpbody = KMail::Util::ByteArray( innerDwPart->AsString() );
if ( mIsRichText ) { // and add our mp/a boundary
- int boundPos = tmpbody.find( '\n' );
+ int boundPos = tmpbody.tqfind( '\n' );
if( -1 < boundPos ) {
TQCString bStr( ";\n boundary=\"" );
bStr += mSaveBoundary.c_str();
@@ -1590,7 +1590,7 @@ void MessageComposer::composeMessage( KMMessage& theMessage,
// manually add a boundary definition to the Content-Type header
if( !mMultipartMixedBoundary.isEmpty() ) {
- int boundPos = mEncodedBody.find( '\n' );
+ int boundPos = mEncodedBody.tqfind( '\n' );
if( -1 < boundPos ) {
// insert new "boundary" parameter
TQCString bStr( ";\n boundary=\"" );
@@ -1600,7 +1600,7 @@ void MessageComposer::composeMessage( KMMessage& theMessage,
}
}
- // tqreplace simple LFs by CRLFs for all MIME supporting CryptPlugs
+ // replace simple LFs by CRLFs for all MIME supporting CryptPlugs
// according to RfC 2633, 3.1.1 Canonicalization
//kdDebug(5006) << "Converting LF to CRLF (see RfC 2633, 3.1.1 Canonicalization)" << endl;
mEncodedBody = KMail::Util::lf2crlf( mEncodedBody );
@@ -1616,7 +1616,7 @@ void MessageComposer::composeMessage( KMMessage& theMessage,
mRc = false;
return;
}
- mRc = processStructuringInfo( TQString::null,
+ mRc = processStructuringInfo( TQString(),
mOldBodyPart.contentDescription(),
mOldBodyPart.typeStr(),
mOldBodyPart.subtypeStr(),
@@ -1700,7 +1700,7 @@ void MessageComposer::encryptMessage( KMMessage* msg,
}
// now do the encrypting:
- // tqreplace simple LFs by CRLFs for all MIME supporting CryptPlugs
+ // replace simple LFs by CRLFs for all MIME supporting CryptPlugs
// according to RfC 2633, 3.1.1 Canonicalization
//kdDebug(5006) << "Converting LF to CRLF (see RfC 2633, 3.1.1 Canonicalization)" << endl;
innerContent = KMail::Util::lf2crlf( innerContent );
@@ -1792,7 +1792,7 @@ void MessageComposer::addBodyAndAttachments( KMMessage* msg,
delete innerDwPart;
innerDwPart = 0;
- // tqreplace simple LFs by CRLFs for all MIME supporting CryptPlugs
+ // replace simple LFs by CRLFs for all MIME supporting CryptPlugs
// according to RfC 2633, 3.1.1 Canonicalization
//kdDebug(5006) << "Converting LF to CRLF (see RfC 2633, 3.1.1 Canonicalization)" << endl;
encodedAttachment = KMail::Util::lf2crlf( encodedAttachment );
@@ -1992,7 +1992,7 @@ bool MessageComposer::processStructuringInfo( const TQString bugURL,
}
if ( binaryHint( format ) ) {
codeCStr += "Content-Transfer-Encoding: base64\n\n";
- codeCStr += KMime::Codec::codecForName( "base64" )->encodeToQCString( ciphertext );
+ codeCStr += KMime::Codec::codecForName( "base64" )->encodeToTQCString( ciphertext );
} else
codeCStr += '\n' + TQCString( ciphertext.data(), ciphertext.size() + 1 );
@@ -2051,7 +2051,7 @@ bool MessageComposer::processStructuringInfo( const TQString bugURL,
TQCString MessageComposer::plainTextFromMarkup( const TQString& markupText )
{
TQTextEdit *hackConspiratorTextEdit = new TQTextEdit( markupText );
- hackConspiratorTextEdit->setTextFormat(Qt::PlainText);
+ hackConspiratorTextEdit->setTextFormat(TQt::PlainText);
if ( !mDisableBreaking ) {
hackConspiratorTextEdit->setWordWrap( TQTextEdit::FixedColumnWidth );
hackConspiratorTextEdit->setWrapColumnOrWidth( mLineBreakColumn );
@@ -2133,7 +2133,7 @@ TQByteArray MessageComposer::breakLinesAndApplyCodec()
kdDebug(5006) << "Added an <LF> on the last line" << endl;
cText += "\n";
}
- return KMail::Util::byteArrayFromQCStringNoDetach( cText );
+ return KMail::Util::byteArrayFromTQCStringNoDetach( cText );
}
@@ -18,11 +18,11 @@
* combinations including the two. You must obey the GNU General
* Public License in all respects for all of the code used other than
- * Qt. If you modify this file, you may extend this exception to
+ * TQt. If you modify this file, you may extend this exception to
* your version of the file, but you are not obligated to do so. If
* you do not wish to do so, delete this exception statement from